@@ -27,10 +27,10 @@ async fn obtain_metadata_none_found() -> miette::Result<()> {
         .create_async()
         .await;
 
-    let client = super::Client::new(
-        "http://example.com",
-        crate::http::reqwest::Client::default(),
-    )?;
+    let client = super::Client::<crate::http::reqwest::Client>::builder()
+        .id("http://example.com")
+        .client(crate::http::reqwest::Client::default())
+        .build()?;
 
     let remote_url = format!("{}/profile", server.url()).parse().unwrap();
     let resp = client.obtain_metadata(&remote_url).await;
@@ -73,10 +73,10 @@ async fn obtain_metadata_via_individual_endpoints() -> miette::Result<()> {
         .create_async()
         .await;
 
-    let client = super::Client::new(
-        "http://example.com",
-        crate::http::reqwest::Client::default(),
-    )?;
+    let client = super::Client::<crate::http::reqwest::Client>::builder()
+        .id("http://example.com")
+        .client(crate::http::reqwest::Client::default())
+        .build()?;
 
     let remote_url = format!("{}/profile", server.url()).parse().unwrap();
     let resp = client.obtain_metadata(&remote_url).await;
@@ -131,10 +131,10 @@ async fn obtain_metadata_via_individual_endpoints_headers() -> miette::Result<()
         .create_async()
         .await;
 
-    let client = super::Client::new(
-        "http://example.com",
-        crate::http::reqwest::Client::default(),
-    )?;
+    let client = super::Client::<crate::http::reqwest::Client>::builder()
+        .id("http://example.com")
+        .client(crate::http::reqwest::Client::default())
+        .build()?;
 
     let remote_url = format!("{}/profile", server.url()).parse().unwrap();
     let resp = client.obtain_metadata(&remote_url).await;
@@ -182,10 +182,10 @@ async fn obtain_metadata_individual_endpoints_missing_auth() -> miette::Result<(
         .create_async()
         .await;
 
-    let client = super::Client::new(
-        "http://example.com",
-        crate::http::reqwest::Client::default(),
-    )?;
+    let client = super::Client::<crate::http::reqwest::Client>::builder()
+        .id("http://example.com")
+        .client(crate::http::reqwest::Client::default())
+        .build()?;
 
     let remote_url = format!("{}/profile", server.url()).parse().unwrap();
     let resp = client.obtain_metadata(&remote_url).await;
@@ -228,10 +228,10 @@ async fn obtain_metadata_individual_endpoints_missing_token() -> miette::Result<
         .create_async()
         .await;
 
-    let client = super::Client::new(
-        "http://example.com",
-        crate::http::reqwest::Client::default(),
-    )?;
+    let client = super::Client::<crate::http::reqwest::Client>::builder()
+        .id("http://example.com")
+        .client(crate::http::reqwest::Client::default())
+        .build()?;
 
     let remote_url = format!("{}/profile", server.url()).parse().unwrap();
     let resp = client.obtain_metadata(&remote_url).await;
@@ -275,10 +275,10 @@ async fn obtain_metadata_individual_endpoints_relative_urls() -> miette::Result<
         .create_async()
         .await;
 
-    let client = super::Client::new(
-        "http://example.com",
-        crate::http::reqwest::Client::default(),
-    )?;
+    let client = super::Client::<crate::http::reqwest::Client>::builder()
+        .id("http://example.com")
+        .client(crate::http::reqwest::Client::default())
+        .build()?;
 
     let remote_url = format!("{}/profile", server.url()).parse().unwrap();
     let resp = client.obtain_metadata(&remote_url).await;
@@ -346,10 +346,10 @@ async fn obtain_metadata_fallback_priority() -> miette::Result<()> {
         .create_async()
         .await;
 
-    let client = super::Client::new(
-        "http://example.com",
-        crate::http::reqwest::Client::default(),
-    )?;
+    let client = super::Client::<crate::http::reqwest::Client>::builder()
+        .id("http://example.com")
+        .client(crate::http::reqwest::Client::default())
+        .build()?;
 
     let remote_url = format!("{}/profile", server.url()).parse().unwrap();
     let resp = client.obtain_metadata(&remote_url).await;
@@ -408,10 +408,10 @@ async fn obtain_metadata_via_endpoint_headers() -> miette::Result<()> {
         .create_async()
         .await;
 
-    let client = super::Client::new(
-        "http://example.com",
-        crate::http::reqwest::Client::default(),
-    )?;
+    let client = super::Client::<crate::http::reqwest::Client>::builder()
+        .id("http://example.com")
+        .client(crate::http::reqwest::Client::default())
+        .build()?;
 
     let remote_url = format!("{}/profile", server.url()).parse().unwrap();
     let resp = client.obtain_metadata(&remote_url).await;
