@@ -13,6 +13,11 @@ use crate::{
     standards::micropub::Parameters,
 };
 
+#[cfg(feature = "experimental_batch")]
+mod batch;
+#[cfg(feature = "experimental_batch")]
+pub use batch::{BatchActionResponse, BatchActionResult};
+
 
 #[derive(serde::Serialize, Clone, Debug, PartialEq, Eq)]
 pub struct CreationProperties {
@@ -242,6 +247,13 @@ pub enum Action {
     Delete(url::Url),
     /// <https://micropub.spec.indieweb.org/#delete-p-7>
     Undelete(url::Url),
+    /// Batch operation to execute multiple actions in a single request.
+    ///
+    /// See <https://github.com/indieweb/micropub-extensions/issues/52>
+    #[cfg(feature = "experimental_batch")]
+    Batch {
+        actions: Vec<Action>,
+    },
 }
 
 fn parse_location_into_url(
@@ -390,6 +402,20 @@ impl Action {
                         let (changes, location) = handle_manipulation_response(response)?;
                         Ok(ActionResponse::Undeleted { changes, location })
                     }
+                    #[cfg(feature = "experimental_batch")]
+                    Action::Batch { .. } => {
+                        let expected_codes = [StatusCode::OK, StatusCode::CREATED, StatusCode::ACCEPTED];
+                        if !expected_codes.contains(&response.status()) {
+                            return Err(super::Error::unexpected_status_code(
+                                response.status(),
+                                &expected_codes,
+                            )
+                            .into());
+                        }
+
+                        let batch_response: BatchActionResponse = from_json_value(response)?;
+                        Ok(ActionResponse::Batch(batch_response))
+                    }
                 }
             })
     }
@@ -437,6 +463,17 @@ impl Action {
                 "action": "undelete",
                 "url": undeleted_url
             }),
+            #[cfg(feature = "experimental_batch")]
+            Action::Batch { actions } => {
+                let actions_json: Vec<serde_json::Value> = actions
+                    .iter()
+                    .map(|a| a.into_json())
+                    .collect();
+                serde_json::json!({
+                    "action": "batch",
+                    "actions": actions_json
+                })
+            }
         }
     }
 }
@@ -500,6 +537,22 @@ impl<'de> serde::Deserialize<'de> for Action {
                 .ok_or_else(|| serde::de::Error::missing_field("url"))
                 .and_then(|uv| serde_json::from_value(uv).map_err(serde::de::Error::custom))
                 .map(Self::Undelete)
+        } else if action_value == serde_json::Value::String("batch".into()) {
+            #[cfg(feature = "experimental_batch")]
+            {
+                let actions_value = params
+                    .remove("actions")
+                    .ok_or_else(|| serde::de::Error::missing_field("actions"))?;
+                let actions: Vec<Action> = serde_json::from_value(actions_value)
+                    .map_err(serde::de::Error::custom)?;
+                Ok(Self::Batch { actions })
+            }
+            #[cfg(not(feature = "experimental_batch"))]
+            {
+                Err(serde::de::Error::custom(
+                    "batch actions require the 'experimental_batch' feature to be enabled",
+                ))
+            }
         } else {
             let properties = serde_json::from_value(serde_json::Value::Object(params))
                 .map_err(serde::de::Error::custom)?;
@@ -756,6 +809,13 @@ pub enum ActionResponse {
         location: Option<url::Url>,
         changes: Option<serde_json::Value>,
     },
+
+    /// The batch operation response.
+    /// Contains individual results for each action in the batch.
+    ///
+    /// See <https://github.com/indieweb/micropub-extensions/issues/52>
+    #[cfg(feature = "experimental_batch")]
+    Batch(BatchActionResponse),
 }
 
 mod test;
