@@ -11,7 +11,6 @@ use crate::{
 };
 use http::header::CONTENT_TYPE;
 use microformats::types::{Class, KnownClass};
-use std::collections::BTreeMap;
 
 use crate::{
     algorithms::ptd::Type,
@@ -198,7 +197,8 @@ fn query_response_for_configuration() {
             media_endpoint: None,
             post_types: vec![PostTypeInfo::Simple(Type::Note)],
             channels: Default::default(),
-            syndicate_to: Default::default()
+            syndicate_to: Default::default(),
+            extensions: Default::default()
         })),
         serde_json::from_value(serde_json::json!({
             "q": ["channels"],
@@ -226,7 +226,8 @@ fn query_response_for_configuration_with_syndication() {
                 uid: "magic".into(),
                 name: "cookie".into(),
                 ..Default::default()
-            }]
+            }],
+            extensions: Default::default()
         })),
         serde_json::from_value(serde_json::json!({
             "q": ["channels"],
@@ -254,7 +255,8 @@ fn query_response_for_configuration_with_channels() {
             media_endpoint: None,
             post_types: vec![PostTypeInfo::Simple(Type::Note)],
             channels: Default::default(),
-            syndicate_to: Default::default()
+            syndicate_to: Default::default(),
+            extensions: Default::default()
         })),
         serde_json::from_value(serde_json::json!({
             "q": ["channels"],
@@ -548,8 +550,8 @@ fn source_list_response_with_paging() {
     
     let list = result.unwrap();
     assert_eq!(list.items.len(), 1);
-    assert!(list.paging.latest.is_some());
-    assert_eq!(list.paging.latest.unwrap(), "cursor_token_123");
+    assert!(list.paging.paging.after.is_some());
+    assert_eq!(list.paging.paging.after.unwrap(), "cursor_token_123");
 }
 
 #[test]
@@ -708,8 +710,6 @@ fn syndication_targets_response_serialization() {
 #[test]
 #[cfg(feature = "experimental_syndication")]
 fn syndication_targets_in_response_enum() {
-    use crate::standards::micropub::extension::syndication;
-    
     let json = serde_json::json!({
         "syndicate-to": [
             {
@@ -730,3 +730,94 @@ fn syndication_targets_in_response_enum() {
         other => panic!("Expected SyndicateTo variant, got {:?}", other),
     }
 }
+
+// ============================================================================
+// Tests for extensions field in ConfigurationResponse
+// ============================================================================
+
+#[test]
+fn config_response_extensions_appear_when_present() {
+    // Test that extensions appear in serialized output when populated
+    let config = ConfigurationResponse {
+        q: vec!["source".to_string()],
+        category: vec![],
+        media_endpoint: None,
+        post_types: vec![],
+        #[cfg(feature = "experimental_channels")]
+        channels: vec![],
+        #[cfg(feature = "experimental_syndication")]
+        syndicate_to: vec![],
+        extensions: vec!["batch".to_string(), "channels".to_string()],
+    };
+
+    let json = serde_json::to_value(&config).unwrap();
+    assert_eq!(
+        json.get("extensions"),
+        Some(&serde_json::json!(["batch", "channels"])),
+        "extensions should appear in JSON when populated"
+    );
+}
+
+#[test]
+fn config_response_extensions_skipped_when_empty() {
+    // Test that extensions are not serialized when empty
+    let config = ConfigurationResponse {
+        q: vec!["source".to_string()],
+        category: vec![],
+        media_endpoint: None,
+        post_types: vec![],
+        #[cfg(feature = "experimental_channels")]
+        channels: vec![],
+        #[cfg(feature = "experimental_syndication")]
+        syndicate_to: vec![],
+        extensions: vec![],
+    };
+
+    let json = serde_json::to_value(&config).unwrap();
+    assert_eq!(
+        json.get("extensions"),
+        None,
+        "extensions should be skipped when empty"
+    );
+}
+
+#[test]
+fn config_response_extensions_deserialization() {
+    // Test that extensions can be deserialized from JSON
+    let json = serde_json::json!({
+        "q": ["source", "config"],
+        "extensions": ["batch", "media-query", "custom-extension"]
+    });
+
+    let result: Result<ConfigurationResponse, _> = serde_json::from_value(json);
+    assert!(result.is_ok(), "Failed to deserialize config with extensions");
+
+    let config = result.unwrap();
+    assert_eq!(config.extensions.len(), 3);
+    assert!(config.extensions.contains(&"batch".to_string()));
+    assert!(config.extensions.contains(&"media-query".to_string()));
+    assert!(config.extensions.contains(&"custom-extension".to_string()));
+}
+
+#[test]
+fn config_response_extensions_roundtrip() {
+    // Test full roundtrip serialization/deserialization
+    let original = ConfigurationResponse {
+        q: vec!["source".to_string(), "config".to_string()],
+        category: vec!["tag".to_string()],
+        media_endpoint: Some("https://example.com/media".parse().unwrap()),
+        post_types: vec![PostTypeInfo::Simple(Type::Note)],
+        #[cfg(feature = "experimental_channels")]
+        channels: vec![],
+        #[cfg(feature = "experimental_syndication")]
+        syndicate_to: vec![],
+        extensions: vec!["batch".to_string(), "publish-delay".to_string()],
+    };
+
+    let json = serde_json::to_value(&original).unwrap();
+    let deserialized: ConfigurationResponse = serde_json::from_value(json).unwrap();
+
+    assert_eq!(original.extensions, deserialized.extensions);
+    assert_eq!(original.q, deserialized.q);
+    assert_eq!(original.category, deserialized.category);
+}
