@@ -330,20 +330,20 @@ impl InMemoryMicrosub {
             properties: {
                 let mut props = BTreeMap::new();
                 if let Some(name) = &entry.name {
-                    props.insert("name".to_string(), vec![types::PropertyValue::Plain(name.clone())]);
+                    props.insert("name".to_string(), vec![types::PropertyValue::Plain(name.clone().into())]);
                 }
                 if let Some(content) = &entry.content
                     && let Some(text) = &content.text {
-                        props.insert("content".to_string(), vec![types::PropertyValue::Plain(text.clone())]);
+                        props.insert("content".to_string(), vec![types::PropertyValue::Plain(text.clone().into())]);
                     }
                 if entry.like_of.is_some() {
-                    props.insert("like-of".to_string(), vec![types::PropertyValue::Plain("https://example.com/liked".to_string())]);
+                    props.insert("like-of".to_string(), vec![types::PropertyValue::Plain("https://example.com/liked".to_string().into())]);
                 }
                 if entry.repost_of.is_some() {
-                    props.insert("repost-of".to_string(), vec![types::PropertyValue::Plain("https://example.com/reposted".to_string())]);
+                    props.insert("repost-of".to_string(), vec![types::PropertyValue::Plain("https://example.com/reposted".to_string().into())]);
                 }
                 if entry.in_reply_to.is_some() {
-                    props.insert("in-reply-to".to_string(), vec![types::PropertyValue::Plain("https://example.com/replied".to_string())]);
+                    props.insert("in-reply-to".to_string(), vec![types::PropertyValue::Plain("https://example.com/replied".to_string().into())]);
                 }
                 props
             },
@@ -576,20 +576,20 @@ impl MicrosubServer for InMemoryMicrosub {
             properties: {
                 let mut props = BTreeMap::new();
                 if let Some(name) = &entry.name {
-                    props.insert("name".to_string(), vec![types::PropertyValue::Plain(name.clone())]);
+                    props.insert("name".to_string(), vec![types::PropertyValue::Plain(name.clone().into())]);
                 }
                 if let Some(content) = &entry.content
                     && let Some(text) = &content.text {
-                        props.insert("content".to_string(), vec![types::PropertyValue::Plain(text.clone())]);
+                        props.insert("content".to_string(), vec![types::PropertyValue::Plain(text.clone().into())]);
                     }
                 if entry.like_of.is_some() {
-                    props.insert("like-of".to_string(), vec![types::PropertyValue::Plain("https://example.com/liked".to_string())]);
+                    props.insert("like-of".to_string(), vec![types::PropertyValue::Plain("https://example.com/liked".to_string().into())]);
                 }
                 if entry.repost_of.is_some() {
-                    props.insert("repost-of".to_string(), vec![types::PropertyValue::Plain("https://example.com/reposted".to_string())]);
+                    props.insert("repost-of".to_string(), vec![types::PropertyValue::Plain("https://example.com/reposted".to_string().into())]);
                 }
                 if entry.in_reply_to.is_some() {
-                    props.insert("in-reply-to".to_string(), vec![types::PropertyValue::Plain("https://example.com/replied".to_string())]);
+                    props.insert("in-reply-to".to_string(), vec![types::PropertyValue::Plain("https://example.com/replied".to_string().into())]);
                 }
                 props
             },
