@@ -5,6 +5,12 @@ use time::OffsetDateTime;
 use url::Url;
 use uuid::Uuid;
 
+pub mod discovery;
+pub mod distribute;
+pub mod publish;
+pub mod signature;
+pub mod subscribe;
+
 /// WebSub protocol implementation
 ///
 /// This module provides a complete implementation of the WebSub specification,
@@ -61,14 +67,6 @@ mod test_utils {
         }
     }
 
-    pub fn create_content_with_signature() -> ContentDistribution {
-        let mut content = create_test_content_distribution();
-        content.signature = Some("sha256=test_signature".to_string());
-        content
-    }
-
-
-
     pub fn generate_hmac_signature(secret: &str, body: &[u8]) -> String {
         use hmac::{Hmac, Mac};
         use sha2::Sha256;
@@ -648,6 +646,7 @@ mod trait_tests {
 mod http_integration_tests {
     use super::*;
     use mockito::Mock;
+    use crate::standards::websub::{discovery, distribute, subscribe};
 
     struct TestServer {
         server: mockito::ServerGuard,
@@ -683,13 +682,27 @@ mod http_integration_tests {
                 .create()
         }
 
+        // Hub publish endpoint
+        fn mock_hub_publish_accept(&mut self) -> Mock {
+            self.server.mock("POST", "/hub")
+                .match_body(mockito::Matcher::Regex("hub\\.mode=publish".into()))
+                .match_body(mockito::Matcher::Regex("hub\\.url=".into()))
+                .with_status(202)
+                .create()
+        }
+
         // Subscriber callback for content distribution
         fn mock_subscriber_callback(&mut self, expected_status: u16) -> Mock {
             self.server.mock("POST", "/callback")
                 .match_header("Content-Type", mockito::Matcher::Any)
                 .match_header("X-Hub-Signature", mockito::Matcher::Any)
-                .match_header("Link", mockito::Matcher::Regex("rel=\"hub\"".into()))
-                .match_header("Link", mockito::Matcher::Regex("rel=\"self\"".into()))
+                .match_header(
+                    "Link",
+                    mockito::Matcher::Regex(
+                        "rel=\\\"hub\\\".*rel=\\\"self\\\"|rel=\\\"self\\\".*rel=\\\"hub\\\""
+                            .into(),
+                    ),
+                )
                 .with_status(expected_status as usize)
                 .create()
         }
@@ -710,16 +723,14 @@ mod http_integration_tests {
         let mut server = TestServer::new().await;
         let topic_mock = server.mock_topic_with_hub();
 
-        // Test hub discovery logic
-        let _client = reqwest::Client::new();
-        let _topic_url = format!("{}/feed", server.url());
-        let _expected_hub_url = format!("{}/hub", server.url());
+        let client = crate::http::reqwest::Client::default();
+        let topic_url = Url::parse(&format!("{}/feed", server.url())).unwrap();
+        let expected_hub_url = Url::parse(&format!("{}/hub", server.url())).unwrap();
+
+        let hubs = discovery::discover_hubs(&client, &topic_url).await.unwrap();
 
-        // Verify the mock was called correctly
         topic_mock.assert();
-
-        // In real implementation, verify hubs contain expected_hub_url
-        // assert_eq!(hubs, vec![Url::parse(&expected_hub_url).unwrap()]);
+        assert_eq!(hubs, vec![expected_hub_url]);
     }
 
     #[tokio::test]
@@ -727,46 +738,53 @@ mod http_integration_tests {
         let mut server = TestServer::new().await;
         let callback_mock = server.mock_subscriber_callback(200);
 
-        let _client = reqwest::Client::new();
-        let _callback_url = format!("{}/callback", server.url());
+        let client = crate::http::reqwest::Client::default();
+        let callback_url = Url::parse(&format!("{}/callback", server.url())).unwrap();
+        let hub_url = Url::parse(&format!("{}/hub", server.url())).unwrap();
+        let topic_url = Url::parse(&format!("{}/feed", server.url())).unwrap();
 
-        let _content = test_utils::create_test_content_distribution();
+        let mut content = test_utils::create_test_content_distribution();
+        content.signature = Some("sha256=test_signature".to_string());
 
-        // This would call: distribute_to_callback(&client, &callback_url, &content).await.unwrap();
+        let result = distribute::distribute_to_callback(
+            &client,
+            &hub_url,
+            &topic_url,
+            &callback_url,
+            &content,
+        )
+        .await
+        .unwrap();
 
-        // Verify exact HTTP interaction
         callback_mock.assert();
-
-        // Additional assertions could check:
-        // - Request body matches content.body
-        // - All required headers are present
-        // - Signature is correctly formatted
+        assert_eq!(result.status, DeliveryStatus::Success);
     }
 
     #[tokio::test]
     async fn subscription_automatic_deletion_on_http_410() {
         let mut server = TestServer::new().await;
-        let _gone_mock = server.mock_subscriber_gone();
+        let gone_mock = server.mock_subscriber_gone();
 
-        let mut hub = InMemoryHub::new();
-        let subscription = test_utils::create_active_subscription();
-        let _subscription_id = hub.store_subscription(subscription.clone()).await.unwrap();
+        let client = crate::http::reqwest::Client::default();
+        let callback_url = Url::parse(&format!("{}/callback", server.url())).unwrap();
+        let hub_url = Url::parse(&format!("{}/hub", server.url())).unwrap();
+        let topic_url = Url::parse(&format!("{}/feed", server.url())).unwrap();
 
-        let content = test_utils::create_test_content_distribution();
-        let topic_url = subscription.topic.clone();
+        let mut content = test_utils::create_test_content_distribution();
+        content.signature = Some("sha256=test_signature".to_string());
 
-        let results = hub.distribute_content(&topic_url, content).await.unwrap();
+        let result = distribute::distribute_to_callback(
+            &client,
+            &hub_url,
+            &topic_url,
+            &callback_url,
+            &content,
+        )
+        .await
+        .unwrap();
 
-        // InMemoryHub doesn't actually make HTTP calls, so this test demonstrates
-        // the expected behavior when HTTP 410 is received
-        // In a real implementation with HTTP calls, this would trigger deletion
-
-        // For now, verify the structure is correct
-        assert_eq!(results.len(), 1);
-        assert_eq!(results[0].status, DeliveryStatus::Success);
-
-        // The mock should not be called since InMemoryHub doesn't make HTTP requests
-        // gone_mock.assert(); // This would fail in current implementation
+        gone_mock.assert();
+        assert_eq!(result.status, DeliveryStatus::SubscriptionDeleted);
     }
 
     #[tokio::test]
@@ -774,17 +792,25 @@ mod http_integration_tests {
         let mut server = TestServer::new().await;
         let invalid_callback_url = server.mock_network_failure();
 
-        let _client = reqwest::Client::new();
-        let _content = test_utils::create_test_content_distribution();
+        let client = crate::http::reqwest::Client::default();
+        let callback_url = Url::parse(&invalid_callback_url).unwrap();
+        let hub_url = Url::parse(&format!("{}/hub", server.url())).unwrap();
+        let topic_url = Url::parse(&format!("{}/feed", server.url())).unwrap();
 
-        // This would call: let result = distribute_to_callback(&client, &invalid_callback_url, &content).await;
+        let content = test_utils::create_test_content_distribution();
 
-        // Verify error handling
-        // assert!(matches!(result, Err(WebSubError::Network(_))));
+        let result = distribute::distribute_to_callback(
+            &client,
+            &hub_url,
+            &topic_url,
+            &callback_url,
+            &content,
+        )
+        .await;
 
-        // In real implementation, this would test timeout/connection failures
-        // For now, just verify the URL construction
-        assert!(invalid_callback_url.contains("/nonexistent"));
+        assert!(result.is_ok());
+        let result = result.unwrap();
+        assert_eq!(result.status, DeliveryStatus::TemporaryFailure);
     }
 
     #[tokio::test]
@@ -792,14 +818,44 @@ mod http_integration_tests {
         let mut server = TestServer::new().await;
         let subscription_mock = server.mock_hub_subscription_accept();
 
-        let _client = reqwest::Client::new();
-        let _hub_url = format!("{}/hub", server.url());
+        let client = crate::http::reqwest::Client::default();
+        let hub_url = Url::parse(&format!("{}/hub", server.url())).unwrap();
 
-        // This would send a subscription request to the hub
-        // let result = send_subscription_request(&client, &hub_url, subscription_data).await.unwrap();
+        let request = SubscribeRequest {
+            topic: Url::parse(&format!("{}/feed", server.url())).unwrap(),
+            callback: Url::parse(&format!("{}/callback", server.url())).unwrap(),
+            secret: Some("secret".to_string()),
+            lease_seconds: Some(3600),
+        };
+
+        let result = subscribe::send_subscription_request(
+            &client,
+            &hub_url,
+            &request,
+            SubscriptionMode::Subscribe,
+        )
+        .await
+        .unwrap();
 
-        // Verify the subscription request was accepted
         subscription_mock.assert();
+        assert_eq!(result.status, http::StatusCode::ACCEPTED);
+    }
+
+    #[tokio::test]
+    async fn hub_publish_endpoint_accepts_valid_requests() {
+        let mut server = TestServer::new().await;
+        let publish_mock = server.mock_hub_publish_accept();
+
+        let client = crate::http::reqwest::Client::default();
+        let hub_url = Url::parse(&format!("{}/hub", server.url())).unwrap();
+        let topic_url = Url::parse(&format!("{}/feed", server.url())).unwrap();
+
+        let result = crate::standards::websub::publish::publish(&client, &hub_url, &topic_url)
+            .await
+            .unwrap();
+
+        publish_mock.assert();
+        assert_eq!(result.status, http::StatusCode::ACCEPTED);
     }
 
     #[tokio::test]
@@ -812,14 +868,26 @@ mod http_integration_tests {
             .with_status(200)
             .create();
 
-        let _client = reqwest::Client::new();
-        let _callback_url = format!("{}/callback", server.url());
-
-        let content = test_utils::create_test_content_distribution();
+        let client = crate::http::reqwest::Client::default();
+        let callback_url = Url::parse(&format!("{}/callback", server.url())).unwrap();
+        let hub_url = Url::parse(&format!("{}/hub", server.url())).unwrap();
+        let topic_url = Url::parse(&format!("{}/feed", server.url())).unwrap();
+        let mut content = test_utils::create_test_content_distribution();
+        content.signature = Some("sha256=test_signature".to_string());
         assert_eq!(content.content_type, "application/atom+xml");
 
-        // This would verify content-type header is sent correctly
+        let result = distribute::distribute_to_callback(
+            &client,
+            &hub_url,
+            &topic_url,
+            &callback_url,
+            &content,
+        )
+        .await
+        .unwrap();
+
         callback_mock.assert();
+        assert_eq!(result.status, DeliveryStatus::Success);
     }
 
     #[tokio::test]
@@ -828,13 +896,26 @@ mod http_integration_tests {
 
         let callback_mock = server.mock_subscriber_callback(200);
 
-        let _client = reqwest::Client::new();
-        let _callback_url = format!("{}/callback", server.url());
+        let client = crate::http::reqwest::Client::default();
+        let callback_url = Url::parse(&format!("{}/callback", server.url())).unwrap();
+        let hub_url = Url::parse(&format!("{}/hub", server.url())).unwrap();
+        let topic_url = Url::parse(&format!("{}/feed", server.url())).unwrap();
 
-        let _content = test_utils::create_test_content_distribution();
+        let mut content = test_utils::create_test_content_distribution();
+        content.signature = Some("sha256=test_signature".to_string());
+
+        let result = distribute::distribute_to_callback(
+            &client,
+            &hub_url,
+            &topic_url,
+            &callback_url,
+            &content,
+        )
+        .await
+        .unwrap();
 
-        // This would verify Link headers are present and correct
         callback_mock.assert();
+        assert_eq!(result.status, DeliveryStatus::Success);
     }
 }
 
@@ -847,9 +928,15 @@ mod compliance_tests {
         // Test RFC 8288 Link header parsing
         // Verify rel="hub" and rel="self" handling
 
-        // This would test that Link headers are properly formatted
-        // according to the WebSub specification
-        // For now, this is a placeholder for future implementation
+        let link_header = "<https://example.com/hub>; rel=\"hub\", <https://example.com/feed>; rel=\"self\"";
+        let header_value = http::HeaderValue::from_str(link_header).unwrap();
+        let base_url = Url::parse("https://example.com/feed").unwrap();
+
+        let hubs = crate::algorithms::link_rel::get_rels_for_header(&header_value, "hub", &base_url);
+        let selfs = crate::algorithms::link_rel::get_rels_for_header(&header_value, "self", &base_url);
+
+        assert_eq!(hubs, vec![Url::parse("https://example.com/hub").unwrap()]);
+        assert_eq!(selfs, vec![Url::parse("https://example.com/feed").unwrap()]);
     }
 
     #[tokio::test]
@@ -858,7 +945,13 @@ mod compliance_tests {
         // Test Content-Type preservation
         // Validate X-Hub-Signature format
 
-        let content = test_utils::create_content_with_signature();
+        let body = b"test content";
+        let signature = crate::standards::websub::signature::sign("test_secret", body).unwrap();
+        let content = ContentDistribution {
+            content_type: "application/atom+xml".to_string(),
+            body: crate::http::Body::Bytes(body.to_vec()),
+            signature: Some(signature),
+        };
 
         // Verify content distribution includes required headers
         assert_eq!(content.content_type, "application/atom+xml");
@@ -896,21 +989,19 @@ mod compliance_tests {
         let subscription = test_utils::create_test_subscription();
         assert_eq!(subscription.status, SubscriptionStatus::Pending);
 
-        // 2. Store subscription (becomes active)
+        // 2. Store subscription
         let _id = hub.store_subscription(subscription.clone()).await.unwrap();
 
-        // 3. Verify subscription is active
+        // 3. Verify subscription is not active yet
         let subscriptions = hub.subscriptions_for_topic(&subscription.topic).await.unwrap();
-        assert_eq!(subscriptions.len(), 1);
-        assert_eq!(subscriptions[0].status, SubscriptionStatus::Active);
+        assert_eq!(subscriptions.len(), 0);
 
         // 4. Distribute content
         let content = test_utils::create_test_content_distribution();
         let results = hub.distribute_content(&subscription.topic, content).await.unwrap();
 
         // 5. Verify delivery
-        assert_eq!(results.len(), 1);
-        assert_eq!(results[0].status, DeliveryStatus::Success);
+        assert_eq!(results.len(), 0);
     }
 
     #[tokio::test]
@@ -925,14 +1016,17 @@ mod compliance_tests {
         // 500 -> TemporaryFailure
 
         // Since InMemoryHub doesn't make HTTP calls, this tests the expected behavior
-        let hub = InMemoryHub::new();
-        let content = test_utils::create_test_content_distribution();
-        let topic_url = Url::parse("https://example.com/feed").unwrap();
+        let response_mapping = vec![
+            (http::StatusCode::OK, DeliveryStatus::Success),
+            (http::StatusCode::GONE, DeliveryStatus::SubscriptionDeleted),
+            (http::StatusCode::NOT_FOUND, DeliveryStatus::PermanentFailure),
+            (http::StatusCode::INTERNAL_SERVER_ERROR, DeliveryStatus::TemporaryFailure),
+        ];
 
-        let results = hub.distribute_content(&topic_url, content).await.unwrap();
-
-        // With no subscribers, results should be empty
-        assert_eq!(results.len(), 0);
+        for (status, expected) in response_mapping {
+            let (got, _message) = crate::standards::websub::distribute::map_status(status);
+            assert_eq!(got, expected);
+        }
     }
 
     #[tokio::test]
@@ -1075,4 +1169,3 @@ pub struct SubscribeRequest {
     /// Requested lease duration in seconds
     pub lease_seconds: Option<u32>,
 }
-
